# #####################################################################
# DeMix, Deconvolution for Mixed cancer genome
# Developed by Jaeil Ahn.
# Updated date : 12/01/2012
# Verson : v1.0.0
# Article : DeMix : Decovolution for Mixed cacer genomes
# using raw measured data.
#
# How to use : 
# First load function : using 'source("TumorH.R");'
#
# Function name : Rdemix
# 
# Parameters
#
# 1. inputmat1 : matrix after RMA normalization.  G*S matrix 
#  where G is the number of genes and S is the number of samples.
#
# 2. groupid : vector of indicators whether the sample is mixed or not. 
# For matched 6 samples ex c(0,1,0,1, 0, 1)
#
# 3. cit=64  which tells the bit of the machine. it can be 32 bit for some machines
#
# 4. matched : if sample are matched, we need to specifiy matched=1 otherwise matched =0
# 
# 5. nref : if we have reference genes, just indicate the row numbers of those genes.
# Not implemented in this version.
#
# 6. nstart : Number of initial values for phi. The running time is proportional to 'nstart'
# 
# return value : 
#   1. phis : mixed proportions
#   2. decov : deconvolved expressions after log-transformed corresponding to mixed samples.
# #####################################################################



rm(list=ls(all=TRUE))
setwd('/Users/jaeilahn/CNV/CNV/Grid/R_pack/');

# Example maqc1 data
rnadata<-as.matrix(read.table("Rmaqcdata1.txt", header=FALSE ))
rnadata2<-as.matrix(read.table("Rmaqcdata1ori.txt", header=FALSE ))



nabsv<-(apply(rnadata[,1:5], 1, mean) >8 & abs(apply(rnadata[,1:5], 1, mean)-apply(rnadata2[,1:5], 1, mean) )>3 & abs(2^apply(rnadata[,1:5], 1, mean)-2^apply(rnadata[,1:5], 1, mean) )<2500)



rnadata=rnadata[nabsv,]
rnadataT<-rnadata2[nabsv,]
refdata2<-cbind((apply(rnadataT, 1, mean)), (apply(rnadataT, 1 , sd))^2);


source("TumorHv1L.R");

# define group 0 for normal 1 for mixed
cnvgroup<-c(rep(0, 5), rep(1, 10)); # maqc 


cbit=64;
matched=0;
nstart=2
inputmat1<-rnadata


testr<-Rdemix(inputmat1, cnvgroup, cbit, matched, 1, refdata2, nstart, 1)

plot(2^refdata2[,1]-2^inputmat1[,1],2^inputmat1[,6]-2^inputmat1[,1], xlim=c(-5000,5000), ylim=c(-5000,5000));

testr$phi

testr$decov[1:5,1:5 ]



