# #####################################################################
# DeMix, Deconvolution for Mixed cancer genome
# Developed by Jaeil Ahn.
# Updated date : 11/01/2012
# Article : DeMix : Decovolution for Mixed cacer genomes
# using raw measured data.

# How to use : 
# 
# inputmat1 : matrix after RMA normalization.  G*S matrix 
# where G is the number of genes and S is the number of samples.
#
# groupid : vector of indicators whether the sample is mixed or not. 
# For matched 6 samples ex c(0,1,0,1, 0, 1)
#
# cit=64  which tells the bit of the machine. it can be 32 bit for some machines
#
# matched : if sample are matched, we need to specifiy matched=1 otherwise matched =0
# nref : if we have reference genes, just indicate the row numbers of those genes.
# #####################################################################




Rdemix <- function(inputmat1, groupid, cbit, matched, nref, refmat, nstart, nhuman) {
	if(!is.matrix(inputmat1)) stop("argument1 must be a matrix");
	if(!is.vector(groupid)) stop("argument2 must be a vector");
	
	if(nref==1){
		if(!is.matrix(refmat)) stop("argument7 must be a matrix if reference genes are ready");
	}
	
	nsub <- as.integer(dim(inputmat1)[2])
	wgenes <- as.integer(dim(inputmat1)[1])
	
	dataarray1 <- (as.array(matrix(inputmat1, nrow = 1, byrow = F)))
	groupid<-(as.array(groupid))
	
	# Default is human.
	if(nhuman>1) nhuman=1;
	
	nP=1
	#nref=0
	nstart=nstart
	refarray1 <- (as.array(matrix(refmat, nrow = 1, byrow = F)))
	
	dyn.load("demixv1L.so")
	
	rres <- .C("demixft", dataarray1, as.integer(groupid), as.integer(nsub), as.integer(wgenes),  as.integer(cbit), 
						 as.integer(matched), as.integer(nref), refarray1, as.integer(nhuman), 
						 as.integer(nstart), rep(0, nsub), rep(0, nsub*wgenes))	
	
	
	outcome2<-matrix(rres[[12]], ncol=(nsub) , nrow=wgenes, byrow = T)

	outcome1<-as.vector(rres[[11]])
	outcome1<-outcome1[groupid==1]
	
	return(list(phi = outcome1, decov = outcome2))
}



# Manual
# R CMD SHLIB demix.c
# R CMD SHLIB nocnv.c
# dyn.load("main.so")
# source("tmean2.R");
# R   CMD SHLIB 	rna.c				 
					 
# R CMD SHLIB demixv1.c

